@@ -1,6 +1,6 @@
 __author__ = 'szednik'
 
-from rdflib import Literal, BNode, Namespace, URIRef, Graph, RDF, RDFS, XSD
+from rdflib import Literal, BNode, Namespace, URIRef, Graph, Dataset, RDF, RDFS, XSD
 import rdflib.resource
 
 """
@@ -8,8 +8,11 @@ import rdflib.resource
 """
 
 PROV = Namespace("http://www.w3.org/ns/prov#")
-graph = Graph()
-graph.bind("prov", PROV)
+
+ds = Dataset(default_union=True)
+ds.bind("prov", PROV)
+default_graph = ds
+
 
 config = {
     "useInverseProperties": False
@@ -24,21 +27,36 @@ def using_inverse_properties():
     return config["useInverseProperties"]
 
 
-def clear_graph():
-    graph.remove((None, None, None))
+def clear_graph(bundle=default_graph):
+    bundle.remove((None, None, None))
 
 
-def serialize(format="xml"):
+def serialize(format="xml", bundle=default_graph):
     if format == "json-ld":
-        return graph.serialize(format='json-ld', indent=4).decode()
+        return bundle.serialize(format='json-ld', indent=4).decode()
     elif format == "nt":
-        return graph.serialize(format='nt').decode()
+        return bundle.serialize(format='nt').decode()
     else:
-        return graph.serialize(format=format, encoding="UTF-8").decode(encoding="UTF-8")
+        return bundle.serialize(format=format, encoding="UTF-8").decode(encoding="UTF-8")
 
 
 def bind_ns(prefix, namespace):
-    graph.bind(prefix, Namespace(namespace))
+    ds.namespace_manager.bind(prefix, Namespace(namespace))
+
+
+def _absolutize(uri):
+    if ":" in uri:
+        (prefix, qname) = uri.split(":")
+        for (p, ns) in ds.namespace_manager.namespaces():
+            if prefix == p:
+                uri = ns+qname
+                break
+    return uri
+
+
+def bundle(id):
+    uri = URIRef(_absolutize(id))
+    return ds.graph(identifier=uri)
 
 
 class Resource(rdflib.resource.Resource):
@@ -47,11 +65,14 @@ class Resource(rdflib.resource.Resource):
     Role
     """
 
-    def __init__(self, id=None):
-        super().__init__(graph, self.node(id))
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(bundle, self.node(id))
 
     @staticmethod
     def node(id):
+        """
+        Factory method returning a URIRef if id is not None and a BNode of id is None.
+        """
         if id is None:
             return BNode()
         else:
@@ -59,15 +80,24 @@ class Resource(rdflib.resource.Resource):
 
     @classmethod
     def ensure_type(cls, resource):
+        """
+        Ensure that resource is of python type 'cls'
+        """
         if not isinstance(resource, cls):
             return cls(resource)
         else:
             return resource
 
-    def resource_objects(self, clz, prop):
+    def get_resources(self, clz, prop):
+        """
+        Return a list of values of the property 'prop' as objects of type 'clz'.
+        """
         return [clz.ensure_type(resource) for resource in self.graph.objects(self.identifier, prop)]
 
-    def literal_objects(self, prop):
+    def get_literals(self, prop):
+        """
+        Return a list of values of the property 'prop' as python native literals.
+        """
         return [literal.toPython() for literal in self.graph.objects(self.identifier, prop)]
 
     def set_label(self, label):
@@ -80,7 +110,7 @@ class Resource(rdflib.resource.Resource):
         """
         Return RDFS label of resource
         """
-        return self.literal_objects(RDFS.label)
+        return self.get_literals(RDFS.label)
 
     def add_type(self, rdf_type):
         """
@@ -97,8 +127,8 @@ class Entity(Resource):
     @see: http://www.w3.org/TR/prov-o/#Entity
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Entity)
 
     def set_was_influenced_by(self, resource):
@@ -115,7 +145,7 @@ class Entity(Resource):
         Return all resources that influenced this entity.
         @iri: http://www.w3.org/ns/prov#wasInfluencedBy
         """
-        return self.resource_objects(Resource, PROV.wasInfluencedBy)
+        return self.get_resources(Resource, PROV.wasInfluencedBy)
 
     def set_was_attributed_to(self, agent):
         """
@@ -133,7 +163,7 @@ class Entity(Resource):
         Return all agents this entity was attributed to.
         @iri: http://www.w3.org/ns/prov#wasAttributedTo
         """
-        return self.resource_objects(Agent, PROV.wasAttributedTo)
+        return self.get_resources(Agent, PROV.wasAttributedTo)
 
     def attribution(self, agent, id=None):
         """
@@ -154,7 +184,7 @@ class Entity(Resource):
         Return all attribution relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedAttribution
         """
-        return self.resource_objects(Attribution, PROV.qualifiedAttribution)
+        return self.get_resources(Attribution, PROV.qualifiedAttribution)
 
     def set_was_generated_by(self, activity):
         """
@@ -171,7 +201,7 @@ class Entity(Resource):
         Return all activities this entity was generated by.
         @iri: http://www.w3.org/ns/prov#wasGeneratedBy
         """
-        return self.resource_objects(Activity, PROV.wasGeneratedBy)
+        return self.get_resources(Activity, PROV.wasGeneratedBy)
 
     def generation(self, activity, id=None, datetime=None, role=None):
         """
@@ -196,7 +226,7 @@ class Entity(Resource):
         Return all generation relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedGeneration
         """
-        return self.resource_objects(Generation, PROV.qualifiedGeneration)
+        return self.get_resources(Generation, PROV.qualifiedGeneration)
 
     def set_was_derived_from(self, entity):
         """
@@ -214,7 +244,7 @@ class Entity(Resource):
         Return all entities this entity was derived from.
         @iri: http://www.w3.org/ns/prov#wasDerivedFrom
         """
-        return self.resource_objects(Entity, PROV.wasDerivedFrom)
+        return self.get_resources(Entity, PROV.wasDerivedFrom)
 
     def derivation(self, entity, id=None):
         """
@@ -235,7 +265,7 @@ class Entity(Resource):
         Return all Derivation relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedDerivation
         """
-        return self.resource_objects(Derivation, PROV.qualifiedGeneration)
+        return self.get_resources(Derivation, PROV.qualifiedGeneration)
 
     def set_was_revision_of(self, entity):
         """
@@ -253,7 +283,7 @@ class Entity(Resource):
         Return all entities this entity was a revision of.
         @iri: http://www.w3.org/ns/prov#wasRevisionOf
         """
-        return self.resource_objects(Entity, PROV.wasRevisionOf)
+        return self.get_resources(Entity, PROV.wasRevisionOf)
 
     def revision(self, entity, id=None):
         """
@@ -275,7 +305,7 @@ class Entity(Resource):
         Return all Revision relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedRevision
         """
-        return self.resource_objects(Revision, PROV.qualifiedRevision)
+        return self.get_resources(Revision, PROV.qualifiedRevision)
 
     def set_was_quoted_from(self, entity):
         """
@@ -293,7 +323,7 @@ class Entity(Resource):
         Return all entities this entity was quoted from.
         @iri: http://www.w3.org/ns/prov#wasQuotedFrom
         """
-        return self.resource_objects(Entity, PROV.wasQuotedFrom)
+        return self.get_resources(Entity, PROV.wasQuotedFrom)
 
     def quotation(self, entity, id=None):
         """
@@ -315,7 +345,7 @@ class Entity(Resource):
         Return all quotation relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedQuotation
         """
-        return self.resource_objects(Quotation, PROV.qualifiedQuotation)
+        return self.get_resources(Quotation, PROV.qualifiedQuotation)
 
     def set_had_primary_source(self, entity):
         """
@@ -333,7 +363,7 @@ class Entity(Resource):
         Return all entities that are a primary source for this entity.
         @iri: http://www.w3.org/ns/prov#hadPrimarySource
         """
-        return self.resource_objects(Entity, PROV.hadPrimarySource)
+        return self.get_resources(Entity, PROV.hadPrimarySource)
 
     def primary_source(self, entity, id=None):
         """
@@ -355,7 +385,7 @@ class Entity(Resource):
         Return all primary source relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedPrimarySource
         """
-        return self.resource_objects(PrimarySource, PROV.qualifiedPrimarySource)
+        return self.get_resources(PrimarySource, PROV.qualifiedPrimarySource)
 
     def set_was_invalidated_by(self, activity):
         """
@@ -372,7 +402,7 @@ class Entity(Resource):
         Return all activities that invalidated this entity.
         @iri: http://www.w3.org/ns/prov#wasInvalidatedBy
         """
-        return self.resource_objects(Activity, PROV.wasInvalidatedBy)
+        return self.get_resources(Activity, PROV.wasInvalidatedBy)
 
     def invalidation(self, activity, id=None, datetime=None):
         """
@@ -396,7 +426,7 @@ class Entity(Resource):
         Return all invalidation relationships of this entity.
         @iri: http://www.w3.org/ns/prov#qualifiedInvalidation
         """
-        return self.resource_objects(Invalidation, PROV.qualifiedInvalidation)
+        return self.get_resources(Invalidation, PROV.qualifiedInvalidation)
 
     def set_alternate_of(self, entity):
         """
@@ -412,7 +442,7 @@ class Entity(Resource):
         Return all entities that are alternates of this entity.
         @iri: http://www.w3.org/ns/prov#alternateOf
         """
-        return self.resource_objects(Entity, PROV.alternateOf)
+        return self.get_resources(Entity, PROV.alternateOf)
 
     def set_specialization_of(self, entity):
         """
@@ -430,7 +460,7 @@ class Entity(Resource):
         Return all entities that that this entity is a specialization of.
         @iri: http://www.w3.org/ns/prov#specializationOf
         """
-        return self.resource_objects(Entity, PROV.specializationOf)
+        return self.get_resources(Entity, PROV.specializationOf)
 
     def set_at_location(self, location):
         """
@@ -447,7 +477,7 @@ class Entity(Resource):
         Return all locations for this entity.
         @iri: http://www.w3.org/ns/prov#atLocation
         """
-        return self.resource_objects(Location, PROV.atLocation)
+        return self.get_resources(Location, PROV.atLocation)
 
     def set_generated_at_time(self, datetime):
         """
@@ -500,8 +530,8 @@ class Bundle(Entity):
     @see: http://www.w3.org/TR/prov-o/#Bundle
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Bundle)
 
 
@@ -513,8 +543,8 @@ class Collection(Entity):
     @see: http://www.w3.org/TR/prov-o/#Collection
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Collection)
 
     def set_had_member(self, entity):
@@ -533,7 +563,7 @@ class Collection(Entity):
         Return all entities that were members of this collection.
         @iri: http://www.w3.org/ns/prov#hadMember
         """
-        return self.resource_objects(Entity, PROV.hadMember)
+        return self.get_resources(Entity, PROV.hadMember)
 
     def get_member_count(self):
         """
@@ -549,8 +579,8 @@ class EmptyCollection(Collection):
     @see: http://www.w3.org/TR/prov-o/#EmptyCollection
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.EmptyCollection)
 
     def set_had_member(self, entity):
@@ -573,8 +603,8 @@ class Plan(Entity):
     @see: http://www.w3.org/TR/prov-o/#Plan
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Plan)
 
 
@@ -587,8 +617,8 @@ class Location(Resource):
     @see: http://www.w3.org/TR/prov-o/#Location
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Location)
 
 
@@ -600,8 +630,8 @@ class Activity(Resource):
     @see: http://www.w3.org/TR/prov-o/#Activity
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Activity)
 
     def set_influenced(self, entity):
@@ -617,7 +647,7 @@ class Activity(Resource):
         Return all entities that were influenced by this activity.
         @iri: http://www.w3.org/ns/prov#influenced
         """
-        return self.resource_objects(Entity, PROV.influenced)
+        return self.get_resources(Entity, PROV.influenced)
 
     def set_was_influenced_by(self, resource):
         """
@@ -650,7 +680,7 @@ class Activity(Resource):
         Return all entities used by this activity.
         @iri: http://www.w3.org/ns/prov#used
         """
-        return self.resource_objects(Entity, PROV.used)
+        return self.get_resources(Entity, PROV.used)
 
     def usage(self, entity, id=None, datetime=None, role=None, location=None):
         """
@@ -677,7 +707,7 @@ class Activity(Resource):
         Return all usage relationships of this activity.
         @iri: http://www.w3.org/ns/prov#qualifiedUsage
         """
-        return self.resource_objects(Usage, PROV.qualifiedUsage)
+        return self.get_resources(Usage, PROV.qualifiedUsage)
 
     def set_generated(self, entity):
         """
@@ -694,7 +724,7 @@ class Activity(Resource):
         Return all entities generated by this activity.
         @iri: http://www.w3.org/ns/prov#generated
         """
-        return self.resource_objects(Entity, PROV.generated)
+        return self.get_resources(Entity, PROV.generated)
 
     def set_invalidated(self, entity):
         """
@@ -711,7 +741,7 @@ class Activity(Resource):
         Return all entities invalided by this activity.
         @iri: http://www.w3.org/ns/prov#invalidated
         """
-        return self.resource_objects(Entity, PROV.invalidated)
+        return self.get_resources(Entity, PROV.invalidated)
 
     def set_was_informed_by(self, activity):
         """
@@ -729,7 +759,7 @@ class Activity(Resource):
         Return all activities that informed this activity.
         @iri: http://www.w3.org/ns/prov#wasInformedBy
         """
-        return self.resource_objects(Activity, PROV.wasInformedBy)
+        return self.get_resources(Activity, PROV.wasInformedBy)
 
     def communication(self, activity, id=None, role=None):
         """
@@ -752,7 +782,7 @@ class Activity(Resource):
         Return all communication relationships for this activity.
         @iri: http://www.w3.org/ns/prov#qualifiedCommunication
         """
-        return self.resource_objects(Communication, PROV.qualifiedCommunication)
+        return self.get_resources(Communication, PROV.qualifiedCommunication)
 
     def set_was_associated_with(self, agent):
         """
@@ -770,7 +800,7 @@ class Activity(Resource):
         Return all agents associated with this activity
         @iri: http://www.w3.org/ns/prov#wasAssociatedWith
         """
-        return self.resource_objects(Agent, PROV.wasAssociatedWith)
+        return self.get_resources(Agent, PROV.wasAssociatedWith)
 
     def association(self, agent, id=None, plan=None, role=None):
         """
@@ -795,7 +825,7 @@ class Activity(Resource):
         Return all association relationships for this activity.
         @iri: http://www.w3.org/ns/prov#qualifiedAssociation
         """
-        return self.resource_objects(Association, PROV.qualifiedAssociation)
+        return self.get_resources(Association, PROV.qualifiedAssociation)
 
     def set_was_started_by(self, entity):
         """
@@ -813,7 +843,7 @@ class Activity(Resource):
         Return all entities that started this activity.
         @iri: http://www.w3.org/ns/prov#wasStartedBy
         """
-        return self.resource_objects(Entity, PROV.wasStartedBy)
+        return self.get_resources(Entity, PROV.wasStartedBy)
 
     def start(self, entity, id=None, datetime=None, location=None):
         """
@@ -839,7 +869,7 @@ class Activity(Resource):
         Return all start relationships for this activity.
         @iri: http://www.w3.org/ns/prov#qualifiedStart
         """
-        return self.resource_objects(Start, PROV.qualifiedStart)
+        return self.get_resources(Start, PROV.qualifiedStart)
 
     def set_was_ended_by(self, entity):
         """
@@ -857,7 +887,7 @@ class Activity(Resource):
         Return all entities that ended this activity.
         @iri: http://www.w3.org/ns/prov#wasEndedBy
         """
-        return self.resource_objects(Entity, PROV.wasEndedBy)
+        return self.get_resources(Entity, PROV.wasEndedBy)
 
     def end(self, entity, id=None, datetime=None, location=None):
         """
@@ -883,7 +913,7 @@ class Activity(Resource):
         Return all end relationships for this activity.
         @iri: http://www.w3.org/ns/prov#qualifiedEnd
         """
-        return self.resource_objects(End, PROV.qualifiedEnd)
+        return self.get_resources(End, PROV.qualifiedEnd)
 
     def set_at_location(self, location):
         """
@@ -900,7 +930,7 @@ class Activity(Resource):
         Return all locations for this activity.
         @iri: http://www.w3.org/ns/prov#atLocation
         """
-        return self.resource_objects(Location, PROV.atLocation)
+        return self.get_resources(Location, PROV.atLocation)
 
     def set_started_at_time(self, datetime):
         """
@@ -939,8 +969,8 @@ class Agent(Resource):
     @see: http://www.w3.org/TR/prov-o/#Agent
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Agent)
 
     def set_was_influenced_by(self, resource):
@@ -955,7 +985,7 @@ class Agent(Resource):
         Return all resources that influenced this agent.
         @iri: http://www.w3.org/ns/prov#wasInfluencedBy
         """
-        return self.resource_objects(Resource, PROV.wasInfluencedBy)
+        return self.get_resources(Resource, PROV.wasInfluencedBy)
 
     def set_acted_on_behalf_of(self, agent):
         """
@@ -973,7 +1003,7 @@ class Agent(Resource):
         Return all agents this agent has acted on behalf of.
         @iri: http://www.w3.org/ns/prov#actedOnBehalfOf
         """
-        return self.resource_objects(Agent, PROV.actedOnBehalfOf)
+        return self.get_resources(Agent, PROV.actedOnBehalfOf)
 
     def delegation(self, agent, id=None, role=None):
         """
@@ -996,7 +1026,7 @@ class Agent(Resource):
         Return all delegation relationships for this agent.
         @iri: http://www.w3.org/ns/prov#qualifiedDelegation
         """
-        return self.resource_objects(Delegation, PROV.qualifiedDelegation)
+        return self.get_resources(Delegation, PROV.qualifiedDelegation)
 
     def set_at_location(self, location):
         """
@@ -1013,7 +1043,7 @@ class Agent(Resource):
         Return all locations for this agent.
         @iri: http://www.w3.org/ns/prov#atLocation
         """
-        return self.resource_objects(Location, PROV.atLocation)
+        return self.get_resources(Location, PROV.atLocation)
 
 
 class Person(Agent):
@@ -1023,8 +1053,8 @@ class Person(Agent):
     @see: http://www.w3.org/TR/prov-o/#Person
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Person)
 
 
@@ -1035,8 +1065,8 @@ class Organization(Agent):
     @see: http://www.w3.org/ns/prov#Organization
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Organization)
 
 
@@ -1047,8 +1077,8 @@ class SoftwareAgent(Agent):
     @see: http://www.w3.org/TR/prov-o/#SoftwareAgent
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.SoftwareAgent)
 
 
@@ -1062,8 +1092,8 @@ class InstantaneousEvent(Resource):
     @see: http://www.w3.org/TR/prov-o/#InstantaneousEvent
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.InstantaneousEvent)
 
     def set_at_location(self, location):
@@ -1081,7 +1111,7 @@ class InstantaneousEvent(Resource):
         Return all locations for this event.
         @iri: http://www.w3.org/ns/prov#atLocation
         """
-        return self.resource_objects(Location, PROV.atLocation)
+        return self.get_resources(Location, PROV.atLocation)
 
     def set_at_time(self, datetime):
         """
@@ -1110,7 +1140,7 @@ class InstantaneousEvent(Resource):
         Return all roles associated with this event.
         @iri: http://www.w3.org/ns/prov#hadRole
         """
-        return self.resource_objects(Role, PROV.hadRole)
+        return self.get_resources(Role, PROV.hadRole)
 
 
 class Influence(Resource):
@@ -1122,8 +1152,8 @@ class Influence(Resource):
     @see: http://www.w3.org/TR/prov-o/#Influence
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Influence)
 
     def set_had_role(self, role):
@@ -1139,7 +1169,7 @@ class Influence(Resource):
         Return all roles associated with this influence.
         @iri: http://www.w3.org/ns/prov#hadRole
         """
-        return self.resource_objects(Role, PROV.hadRole)
+        return self.get_resources(Role, PROV.hadRole)
 
     def set_had_activity(self, activity):
         """
@@ -1156,7 +1186,7 @@ class Influence(Resource):
         or was the responsibility of some entity.
         @iri: @iri: http://www.w3.org/ns/prov#hadActivity
         """
-        return self.resource_objects(Activity, PROV.hadActivity)
+        return self.get_resources(Activity, PROV.hadActivity)
 
 
 class ActivityInfluence(Influence):
@@ -1167,8 +1197,8 @@ class ActivityInfluence(Influence):
     @see: http://www.w3.org/TR/prov-o/#ActivityInfluence
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
 
     def set_activity(self, activity):
         """
@@ -1186,7 +1216,7 @@ class ActivityInfluence(Influence):
         generation, invalidation, communication, or other.
         @iri: http://www.w3.org/ns/prov#activity
         """
-        return self.resource_objects(Activity, PROV.activity)
+        return self.get_resources(Activity, PROV.activity)
 
 
 class AgentInfluence(Influence):
@@ -1197,8 +1227,8 @@ class AgentInfluence(Influence):
     @see: http://www.w3.org/TR/prov-o/#AgentInfluence
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
 
     def set_agent(self, agent):
         """
@@ -1216,7 +1246,7 @@ class AgentInfluence(Influence):
         of attribution, association, delegation, or other.
         @iri: http://www.w3.org/ns/prov#agent
         """
-        return self.resource_objects(Agent, PROV.agent)
+        return self.get_resources(Agent, PROV.agent)
 
 
 class EntityInfluence(Influence):
@@ -1227,8 +1257,8 @@ class EntityInfluence(Influence):
     @see: http://www.w3.org/TR/prov-o/#EntityInfluence
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id, bundle=bundle)
 
     def set_entity(self, entity):
         """
@@ -1246,7 +1276,7 @@ class EntityInfluence(Influence):
         by means of usage, start, end, derivation, or other.
         @iri: http://www.w3.org/ns/prov#entity
         """
-        self.resource_objects(Entity, PROV.entity)
+        self.get_resources(Entity, PROV.entity)
 
 
 class Generation(InstantaneousEvent, ActivityInfluence):
@@ -1257,8 +1287,8 @@ class Generation(InstantaneousEvent, ActivityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Generation
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Generation)
 
 
@@ -1272,8 +1302,8 @@ class Start(InstantaneousEvent, EntityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Start
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id, bundle=bundle)
         self.add_type(PROV.Start)
 
 
@@ -1287,8 +1317,8 @@ class End(InstantaneousEvent, EntityInfluence):
     @see: http://www.w3.org/TR/prov-o/#End
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.End)
 
 
@@ -1301,8 +1331,8 @@ class Invalidation(InstantaneousEvent, ActivityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Invalidation
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Invalidation)
 
 
@@ -1313,8 +1343,8 @@ class Communication(ActivityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Communication
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Communication)
 
 
@@ -1326,8 +1356,8 @@ class Usage(InstantaneousEvent, EntityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Usage
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Usage)
 
 
@@ -1339,8 +1369,8 @@ class Derivation(EntityInfluence):
     @see: http://www.w3.org/TR/prov-o/#Derivation
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Derivation)
 
     def set_had_usage(self, usage):
@@ -1356,7 +1386,7 @@ class Derivation(EntityInfluence):
         Return all usages involved in an entity's derivation.
         @iri: http://www.w3.org/ns/prov#hadUsage
         """
-        return self.resource_objects(Usage, PROV.hadUsage)
+        return self.get_resources(Usage, PROV.hadUsage)
 
     def set_had_generation(self, generation):
         """
@@ -1371,7 +1401,7 @@ class Derivation(EntityInfluence):
         Return all generations involved in an entity's derivation.
         @iri: http://www.w3.org/ns/prov#hadGeneration
         """
-        return self.resource_objects(Generation, PROV.hadGeneration)
+        return self.get_resources(Generation, PROV.hadGeneration)
 
 
 class Revision(Derivation):
@@ -1383,8 +1413,8 @@ class Revision(Derivation):
     @see: http://www.w3.org/TR/prov-o/#Revision
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Revision)
 
 
@@ -1401,8 +1431,8 @@ class PrimarySource(Derivation):
     @see: http://www.w3.org/TR/prov-o/#PrimarySource
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.PrimarySource)
 
 
@@ -1414,8 +1444,8 @@ class Quotation(Derivation):
     @see: http://www.w3.org/TR/prov-o/#Quotation
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Quotation)
 
 
@@ -1430,8 +1460,8 @@ class Delegation(AgentInfluence):
     @see: http://www.w3.org/TR/prov-o/#Delegation
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Delegation)
 
 
@@ -1444,8 +1474,8 @@ class Association(AgentInfluence):
     @see: http://www.w3.org/TR/prov-o/#Association
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Association)
 
     def set_had_plan(self, plan):
@@ -1463,7 +1493,7 @@ class Association(AgentInfluence):
         Return the plan used by the agent in the context of the activity association.
         @iri: http://www.w3.org/ns/prov#hadPlan
         """
-        return self.resource_objects(Plan, PROV.hadPlan)
+        return self.get_resources(Plan, PROV.hadPlan)
 
 
 class Attribution(AgentInfluence):
@@ -1475,8 +1505,8 @@ class Attribution(AgentInfluence):
     @see: http://www.w3.org/TR/prov-o/#Attribution
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Attribution)
 
 
@@ -1488,6 +1518,6 @@ class Role(Resource):
     @see: http://www.w3.org/TR/prov-o/#Role
     """
 
-    def __init__(self, id=None):
-        super().__init__(id)
+    def __init__(self, id=None, bundle=default_graph):
+        super().__init__(id=id, bundle=bundle)
         self.add_type(PROV.Role)
\ No newline at end of file
